{pkgs, ...}: {
  users.users.michael = {
    home = "/Users/michael";
    shell = pkgs.zsh;
  };

  networking = {
    computerName = "neptune";
    hostName = "neptune";
  };

  environment = {
    shells = with pkgs; [zsh];
    variables = {
      EDITOR = "nvim";
      VISUAL = "nvim";
    };
    systemPackages = with pkgs; [
      # Containers
      colima
      unstable.docker-client
      unstable.docker-compose
      # Video
      ffmpeg
      # Java
      checkstyle
      # XCode
      cocoapods
      # Android Development
      android-tools
    ];
  };

  my = {
    aerospace.enable = true;
    neovim.enable = true;
    sketchybar.enable = true;
    spotify.enable = true;
  };

  programs = {
    zsh = {
      enable = true;
      # Make zsh installation work properly with macOS path
      loginShellInit = ''
        if [ -x /usr/libexec/path_helper ]; then
          eval `/usr/libexec/path_helper -s`
        fi
      '';
      enableGlobalCompInit = false;
    };
  };

  security.pam.enableSudoTouchIdAuth = true;

  services = {
    nix-daemon.enable = true;
  };

  system = {
    # Since it's not possible to declare default shell, run this command after build
    activationScripts.postActivation.text = ''sudo chsh -s ${pkgs.zsh}/bin/zsh'';
    stateVersion = 4;
  };
}
